@@ -3,6 +3,11 @@
 function bluer_ugv_swallow_dataset_upload() {
     local options=$1
     local do_metadata=$(bluer_ai_option_int "$options" metadata 1)
+    local mode=$(bluer_ai_option_choice "$options" navigation,yolo yolo)
+
+    local object_name=$BLUER_UGV_SWALLOW_YOLO_DATASET_LIST
+    [[ "$mode" == "navigation" ]] &&
+        object_name=$BLUER_UGV_SWALLOW_NAVIGATION_DATASET_LIST
 
     local upload_options="-"
     [[ "$do_metadata" == 1 ]] &&
@@ -10,5 +15,5 @@ function bluer_ugv_swallow_dataset_upload() {
 
     bluer_objects_upload \
         $upload_options \
-        $BLUER_UGV_SWALLOW_DATASET_LIST
+        $object_name
 }
