@@ -16,7 +16,9 @@ function test_bluer_ugv_help() {
         "@swallow env" \
         "@swallow env cp" \
         "@swallow env list" \
+        "@swallow env set" \
         \
+        "@swallow debug" \
         "@swallow select_target" \
         \
         "@ugv" \
