@@ -14,6 +14,12 @@ BLUER_UGV_SWALLOW_STEERING_SETPOINT = get_env("BLUER_UGV_SWALLOW_STEERING_SETPOI
 
 BLUER_UGV_MOUSEPAD_ENABLED = get_env("BLUER_UGV_MOUSEPAD_ENABLED", 0)
 
-BLUER_UGV_SWALLOW_DATASET_LIST = get_env("BLUER_UGV_SWALLOW_DATASET_LIST", "")
+BLUER_UGV_SWALLOW_NAVIGATION_DATASET_LIST = get_env(
+    "BLUER_UGV_SWALLOW_NAVIGATION_DATASET_LIST"
+)
 
-BLUER_UGV_SWALLOW_MODEL = get_env("BLUER_UGV_SWALLOW_MODEL", "")
+BLUER_UGV_SWALLOW_NAVIGATION_MODEL = get_env("BLUER_UGV_SWALLOW_NAVIGATION_MODEL", "")
+
+BLUER_UGV_SWALLOW_YOLO_MODEL = get_env("BLUER_UGV_SWALLOW_YOLO_MODEL")
+
+BLUER_UGV_SWALLOW_YOLO_DATASET_LIST = get_env("BLUER_UGV_SWALLOW_YOLO_DATASET_LIST")
