@@ -7,11 +7,18 @@ def help_debug(
     tokens: List[str],
     mono: bool,
 ) -> str:
+    args = [
+        "[--generate_gif 0]",
+        "[--save_images 0]",
+    ]
+
     return show_usage(
         [
             "@swallow",
             "debug",
-        ],
+            "[-|<object-name>]",
+        ]
+        + args,
         "debug swallow.",
         mono=mono,
     )
